@@ -17,7 +17,7 @@ from collections import OrderedDict
 from distutils import util
 import os
 import re
-from typing import Callable, Dict, Optional, Sequence, Tuple, Type, Union
+from typing import Dict, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
 from google.api_core import client_options as client_options_lib  # type: ignore
@@ -356,7 +356,7 @@ class InstancesClient(metaclass=InstancesClientMeta):
 
     def list_instances(
         self,
-        request: appengine.ListInstancesRequest = None,
+        request: Union[appengine.ListInstancesRequest, dict] = None,
         *,
         retry: retries.Retry = gapic_v1.method.DEFAULT,
         timeout: float = None,
@@ -369,7 +369,7 @@ class InstancesClient(metaclass=InstancesClientMeta):
         API <https://cloud.google.com/monitoring/api/ref_v3/rest/v3/projects.timeSeries/list>`__.
 
         Args:
-            request (google.cloud.appengine_admin_v1.types.ListInstancesRequest):
+            request (Union[google.cloud.appengine_admin_v1.types.ListInstancesRequest, dict]):
                 The request object. Request message for
                 `Instances.ListInstances`.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
@@ -418,7 +418,7 @@ class InstancesClient(metaclass=InstancesClientMeta):
 
     def get_instance(
         self,
-        request: appengine.GetInstanceRequest = None,
+        request: Union[appengine.GetInstanceRequest, dict] = None,
         *,
         retry: retries.Retry = gapic_v1.method.DEFAULT,
         timeout: float = None,
@@ -427,7 +427,7 @@ class InstancesClient(metaclass=InstancesClientMeta):
         r"""Gets instance information.
 
         Args:
-            request (google.cloud.appengine_admin_v1.types.GetInstanceRequest):
+            request (Union[google.cloud.appengine_admin_v1.types.GetInstanceRequest, dict]):
                 The request object. Request message for
                 `Instances.GetInstance`.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
@@ -469,7 +469,7 @@ class InstancesClient(metaclass=InstancesClientMeta):
 
     def delete_instance(
         self,
-        request: appengine.DeleteInstanceRequest = None,
+        request: Union[appengine.DeleteInstanceRequest, dict] = None,
         *,
         retry: retries.Retry = gapic_v1.method.DEFAULT,
         timeout: float = None,
@@ -492,7 +492,7 @@ class InstancesClient(metaclass=InstancesClientMeta):
         method.
 
         Args:
-            request (google.cloud.appengine_admin_v1.types.DeleteInstanceRequest):
+            request (Union[google.cloud.appengine_admin_v1.types.DeleteInstanceRequest, dict]):
                 The request object. Request message for
                 `Instances.DeleteInstance`.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
@@ -554,7 +554,7 @@ class InstancesClient(metaclass=InstancesClientMeta):
 
     def debug_instance(
         self,
-        request: appengine.DebugInstanceRequest = None,
+        request: Union[appengine.DebugInstanceRequest, dict] = None,
         *,
         retry: retries.Retry = gapic_v1.method.DEFAULT,
         timeout: float = None,
@@ -572,7 +572,7 @@ class InstancesClient(metaclass=InstancesClientMeta):
         environment.
 
         Args:
-            request (google.cloud.appengine_admin_v1.types.DebugInstanceRequest):
+            request (Union[google.cloud.appengine_admin_v1.types.DebugInstanceRequest, dict]):
                 The request object. Request message for
                 `Instances.DebugInstance`.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
